-- Disable the addon if the player is not a hunter:
if select(2, UnitClass("player")) ~= "HUNTER" then
	return DisableAddOn("EZTrap")
end
------------------------------------------------------------------------
-- Create the base frame:
local EZTrap = CreateFrame("Frame", "EZTrap", UIParent)
EZTrap:SetPoint("CENTER", -1, -144)
EZTrap:SetSize(140, 140)

-- Make it draggable and resizable:
EZTrap:SetMovable(true)
EZTrap:SetResizable(true)
EZTrap:EnableMouse(true)
EZTrap:SetMaxResize(140,140)
EZTrap:SetMinResize(70,70)
EZTrap:RegisterForDrag("RightButton", "LeftButton")

EZTrap:SetScript("OnMouseDown", function(self, button)
local shiftDown = IsShiftKeyDown();
  if button == "RightButton" and not self.isMoving then
   self:StartMoving();
   self.isMoving = true;
  elseif ( IsShiftKeyDown() ) and (button == "LeftButton" and not self.isSizing) then
   self:StartSizing();
   self.isSizing = true
  end
end)

EZTrap:SetScript("OnMouseUp", function(self, button)
  if button == "RightButton" and self.isMoving then
   self:StopMovingOrSizing();
   self.isMoving = false; 
  elseif (button == "LeftButton" and self.isSizing) then
   self:StopMovingOrSizing();
   self.isSizing = false
  end
end)

EZTrap:SetScript("OnHide", function(self)
  if ( self.isMoving ) or (self.isSizing) then
   self:StopMovingOrSizing();
   self.isMoving = false;
   self.isSizing = false;
  end
end)

-- Add the background:
EZTrap:SetBackdrop({
	bgFile = [[Interface\Icons\ability_ensnare]], tile = false, tileSize = 0,
	edgeFile = [[Interface\DialogFrame\UI-DialogBox-Border]], edgeSize = 32,
	insets = { left = 16, right = 17, top = 17, bottom = 16,}
})
EZTrap:SetBackdropColor(0,0,0,0.3)
------------------------------------------------------------------------

-- Add a button for Trap Launcher:
local name TRAP_LAUNCHER = GetSpellInfo(77769)
local f = CreateFrame("Button", "Launcher", EZTrap, "SecureActionButtonTemplate")
f:ClearAllPoints()
f:SetPoint("CENTER",0,0)
f:SetSize(60, 20)
f:SetAttribute("type", "spell")
f:SetAttribute("spell", "Trap Launcher")
f:RegisterUnitEvent("UNIT_AURA", "player")
f:SetScript("OnEvent", function()
    local name, _, _, _, _, _, _, _, _, _, spellID = UnitBuff("player", TRAP_LAUNCHER)
   if name then
       f:SetNormalTexture([[Interface\Icons\spell_nature_wispsplode]])
   elseif not name then
       f:SetNormalTexture([[Interface\Icons\ability_hunter_traplauncher]])
   end
end)

------------------------------------------------------------------------

-- Set up a button factory:
local CreateTrapButton
do
	-- Share the same event handler function between buttons
	-- instead of creating duplicate functions:
	    local function TrapButton_OnEvent(self, event, ...)
		local start, duration = GetSpellCooldown(self.spellID)
		if duration > 0 then
			self.cooldown:Show()
			self.cooldown:SetCooldown(start, duration)
		end
	end

	function CreateTrapButton(spellID)
		-- Get the name and icon for the specified spell:
		local spellName, _, spellIcon = GetSpellInfo(spellID)
		if not spellName then
			-- That's not a valid spell ID!
			return
		end

		-- Create the button:
		local button = CreateFrame("Button", "$parent"..gsub(spellName, "[^%a]", ""), EZTrap, "SecureActionButtonTemplate")
		

		-- Set the correct trap spell properties:
		button:SetAttribute("type", "spell")
		button:SetAttribute("spell", spellName)
		button:SetNormalTexture(spellIcon)
		button.spellID = spellID

		-- Add a cooldown to the button:
		local cd = CreateFrame("Cooldown", "$parentCooldown", button, "CooldownFrameTemplate")
		button.cooldown = cd
		cd:SetAllPoints(true)
		cd:Hide()

		-- Update the cooldown when needed:
		button:RegisterEvent("SPELL_UPDATE_COOLDOWN")
		button:SetScript("OnEvent", TrapButton_OnEvent)

		-- Hand the button back to the calling code:
		return button
	end
end

------------------------------------------------------------------------
-- Add a button for Explosive Trap:
local Explosive = CreateTrapButton(13813)
Explosive:ClearAllPoints()
Explosive:SetPoint("TOPLEFT", EZTrap, "TOPLEFT", 10, -10)
Explosive:SetPoint("TOPRIGHT", EZTrap, "CENTER", 0, 0) 
Explosive:SetPoint("BOTTOMLEFT", EZTrap, "CENTER", 0, 6)
Explosive:SetPoint("BOTTOMRIGHT", EZTrap, "CENTER", 0, 6) 
Explosive:SetSize(20, 20)
------------------------------------------------------------------------
-- Add a button for Freezing Trap:
local Freezing = CreateTrapButton(1499)
Freezing:ClearAllPoints()
Freezing:SetPoint("TOPLEFT", Explosive, "BOTTOMLEFT", 3, -15)
Freezing:SetPoint("BOTTOMLEFT", EZTrap, "BOTTOMLEFT", 10, 10)
Freezing:SetPoint("TOPRIGHT", Explosive, "BOTTOMRIGHT", 3, 0)
Freezing:SetSize(60, 20)
------------------------------------------------------------------------
-- Add a button for Ice Trap:
local Ice = CreateTrapButton(13809)
Ice:ClearAllPoints()
Ice:SetPoint("TOPRIGHT", EZTrap, "TOPRIGHT", -10, 0)
Ice:SetPoint("TOPLEFT", Explosive, "TOPRIGHT", 0, 0)
Ice:SetPoint("BOTTOMLEFT", Explosive, "BOTTOMLEFT", 0, 0)
Ice:SetSize(20, 20)
------------------------------------------------------------------------